@@ -9,7 +9,7 @@ from flask.ext.wtf.csrf import CsrfProtect
 from .sqlstats import DB_STATS
 
 
-__version__ = '0.4.9'
+__version__ = '0.4.10'
 
 
 requests_session = requests.Session()
@@ -21,14 +21,15 @@ locale.setlocale(locale.LC_ALL, '')
 
 db = SQLAlchemy()
 
+
+csrf = CsrfProtect()
+
+
 # Ensure models are declared
 from . import models
 from .auth import models
 
 
-csrf = CsrfProtect()
-
-
 def create_app(**kwargs):
     app = Flask('evesrp', **kwargs)
     app.config.from_object('evesrp.default_config')
@@ -44,7 +45,11 @@ def create_app(**kwargs):
     from .auth import principal
     principal.init_app(app)
 
+    before_csrf = list(app.before_request_funcs[None])
     csrf.init_app(app)
+    # Remove the context processor that checks CSRF values. All it is used for
+    # is the template function.
+    app.before_request_funcs[None] = before_csrf
 
     from .views import index, divisions, login, requests, api
     app.add_url_rule(rule='/', view_func=index)
@@ -99,8 +104,9 @@ def _config_requests_session():
         ua_string = current_app.config['USER_AGENT_STRING']
     except KeyError as outer_exc:
         try:
-            ua_string = 'EVE-SRP/0.1 ({})'.format(
-                    current_app.config['USER_AGENT_EMAIL'])
+            ua_string = 'EVE-SRP/{version} ({email})'.format(
+                    email=current_app.config['USER_AGENT_EMAIL'],
+                    version=__version__)
         except KeyError as inner_exc:
             raise inner_exc from outer_exc
     requests_session.headers.update({'User-Agent': ua_string})
