@@ -35,6 +35,9 @@ class Entity(db.Model, AutoID):
     entity_permissions = db.relationship('Permission', collection_class=set,
             back_populates='entity', lazy='dynamic')
 
+    #: The name of the :py:class:`AuthMethod` for this entity.
+    authmethod = db.Column(db.String(50), nullable=False)
+
     @declared_attr
     def __tablename__(cls):
         """SQLAlchemy late-binding attribute to set the table name.
@@ -55,15 +58,9 @@ class Entity(db.Model, AutoID):
             args['polymorphic_on'] = cls.type_
         return args
 
-    @classmethod
-    def authmethod(cls):
-        """:rtype: class
-        :returns: The :py:class:`AuthMethod` for this entity class.
-        """
-        return AuthMethod
-
-    def __init__(self, name, **kwargs):
+    def __init__(self, name, authmethod, **kwargs):
         self.name = name
+        self.authmethod = authmethod
         super(Entity, self).__init__(**kwargs)
 
     def __repr__(self):
@@ -87,7 +84,9 @@ class Entity(db.Model, AutoID):
         if permissions in ('submit', 'review', 'pay'):
             permissions = (permissions,)
         perms = self.permissions.filter(Permission.permission.in_(permissions))
-        return db.session.query(perms.exists()).all()[0]
+        if division is not None:
+            perms = perms.filter_by(division=division)
+        return db.session.query(perms.exists()).all()[0][0]
 
 
 class User(Entity):
@@ -172,6 +171,11 @@ class Note(db.Model, AutoID, Timestamped):
     noter = db.relationship(User, back_populates='notes_made',
             foreign_keys=[noter_id])
 
+    def __init__(self, user, noter, note):
+        self.user = user
+        self.noter = noter
+        self.content = note
+
 
 class Pilot(db.Model, AutoID):
     """Represents an in-game character."""
@@ -226,6 +230,9 @@ class Group(Entity):
 
 class Permission(db.Model, AutoID):
     __tablename__ = 'permission'
+    __table_args__ = (
+        db.UniqueConstraint('division_id', 'entity_id', 'permission'),
+    )
 
     division_id = db.Column(db.Integer, db.ForeignKey('division.id'),
             nullable=False)
